/*
 * Game.c
 *
 *  Created on: Mar 1, 2012
 *      Author: Mateusz
 */
#include "Game.h"
#include "GlobalDefine.h"
#include "Graphisc.h"

uint8 backgroundColor=0b11100000;
uint8 platformColor=0b00011100;
uint8 boxColor=0b00000011;

void InitializeScreen()
{
	LCDClear(0);
	drawBox(5,22,122,108,backgroundColor);
}

void platformMove(short int direction)
{
	drawBox(platform.x,platform.y,platform.xSize,platform.ySize,backgroundColor);
	if(platform.x+direction>4 &&(platform.x+platform.xSize+direction<128))
	{
		platform.x+=direction;
		if(ball.speedY==0)
		{
			if(!GPIO_ReadInputDataBit(GPIOC,LEWO))
			{
				reDrawBall(-1,0);
			}
			else if(!GPIO_ReadInputDataBit(GPIOC,PRAWO))
			{
				reDrawBall(1,0);
			}
		}
	}
	drawBox(platform.x,platform.y,platform.xSize,platform.ySize,platformColor);
}

void InitializeGame()
{
	InitializeScreen();
	boost=7;
	score=0;
	ball.x=64;
	ball.y=119;
	ball.speedX=0;
	ball.speedY=0;
	restart();
	StartNewPlay();
}

void StartNewPlay()
{
	uint8 i;
	uint8 j;
	uint8 k=0;
	platform.xSize=30;
	platform.ySize=5;
	platform.x=51;
	platform.y=124;
	platformMove(0);
	for(i=0;i<6 ;i++)
	{
		for(j=0;j<6-i;j++)
		{
			Targets[k].x=8+j*20+10*i;
			Targets[k].y=23+10*i;
			Targets[k].xSize=18;
			Targets[k].ySize=8;
			Targets[k].avaible=1;
			k++;
		}
	}
	reDraw();

	reDrawBall(0,0);
}

void reDraw()
{
	uint8 i=0;
	for(i=0;i<21;i++)
	{
		if(Targets[i].avaible==1)
		{
			drawBox(Targets[i].x,Targets[i].y,Targets[i].xSize,Targets[i].ySize,boxColor);
		}
		else
		{
		drawBox(Targets[i].x,Targets[i].y,Targets[i].xSize,Targets[i].ySize,backgroundColor);
		}
	}
}

void reDrawBall(int8 speedX,int8 speedY)
{
	drawBall(ball.x,ball.y,backgroundColor,backgroundColor);
	ball.x+=speedX;
	ball.y+=speedY;
	drawBall(ball.x,ball.y, boxColor,backgroundColor);
}

void playStart()
{
	if(ball.speedX==0 && ball.speedY==0)
	{
		ball.speedX=-1;
		ball.speedY=-1;
		SysTick_CLKSourceConfig(SysTick_CLKSource_HCLK_Div8);
		SysTick_Config(90000);
	}
}

uint8 colision()
{
	uint8 colision=0;
	uint8 k=0;
	uint8 unavaible=0;
	for(k=0;k<21;k++)
	{
		if (Targets[k].avaible==1)
		{
			if((Targets[k].x<= ball.x+5) && (ball.x<=Targets[k].x+Targets[k].xSize )&&
					(ball.y<=Targets[k].y+Targets[k].ySize)&&(ball.y+5>=Targets[k].y))
			{
				if(Targets[k].x>= ball.x+5)
				{
					ball.speedX*=-1;
				}
				if(ball.x>=Targets[k].x+Targets[k].xSize )
				{
					ball.speedX*=-1;
				}
				if(ball.y>=Targets[k].y+Targets[k].ySize)
				{
					ball.speedY*=-1;
				}
				if(ball.y+5<=Targets[k].y)
				{
					ball.speedY*=-1;
				}
				colision=1;

			addPoint();
			Targets[k].avaible=0;
			}
		}
		if(Targets[k].avaible==0)
			unavaible++;
	}
	if(ball.x<=5)
	{
		ball.speedX*=-1;
		return 2;
	}
	if(ball.x+5>=126)
	{
		ball.speedX*=-1;
		return 2;
	}
	if(ball.y<=22)
	{
		ball.speedY*=-1;
		return 2;
	}
	if(ball.y+5>=124)
	{
		if((ball.x+6>=platform.x) && (ball.x <= platform.x+platform.xSize))
		{
			ball.speedY*=-1;
			return 3;
		}
		else
		{
			return 4;
		}
	}
	if(unavaible==21)
		return 5;
	return colision;
}

void addPoint()
{
 score++;
}

void Iteration()
{
	if(ball.speedX==-2)
	{
		if(ball.x<=6)
			reDrawBall(-1,ball.speedY);
		else
			reDrawBall(ball.speedX,ball.speedY);
	}
	else if(ball.speedX==2)
	{
		if(ball.x>=120)
			reDrawBall(1,ball.speedY);
		else
			reDrawBall(ball.speedX,ball.speedY);
	}
	else
	reDrawBall(ball.speedX,ball.speedY);

	uint8 col=colision();
	switch(col)
	{
		case 1:
			reDraw();
			break;
		case 4:
			ball.speedX=0;
			ball.speedY=0;
			restart();
			break;
		case 3:
			if(ball.speedY!=0)
			{
				if(!GPIO_ReadInputDataBit(GPIOC,LEWO))
				{
					if(ball.speedX>-2)
					ball.speedX-=1;
				}
				else if(!GPIO_ReadInputDataBit(GPIOC,PRAWO))
				{
					if(ball.speedX<2)
					ball.speedX+=1;
				}
			}

			break;
		case 5:
			if(boost>1)
				boost--;
			restart();
			StartNewPlay();
			break;
	}
	col=0;
}

void restart()
{
		platformMove(51-platform.x);
		ball.speedX=0;
		ball.speedY=0;
		reDrawBall(64-ball.x,119-ball.y);
}
