/**
*****************************************************************************
**
**  File        : main.c
**
**  Abstract    : main function.
**
**  Functions   : main
**
**  Environment : Atollic TrueSTUDIO/STM32
**                STMicroelectronics STM32F10x Standard Peripherals Library
**
**  Distribution: The file is distributed as is, without any warranty
**                of any kind.
**
**  (c)Copyright Atollic AB.
**  You may use this file as-is or modify it according to the needs of your
**  project. Distribution of this file (unmodified or modified) is not
**  permitted. Atollic AB permit registered Atollic TrueSTUDIO(R) users the
**  rights to distribute the assembled, compiled & linked contents of this
**  file as part of an application binary file, provided that it is built
**  using the Atollic TrueSTUDIO(R) toolchain.
**
**
*****************************************************************************
*/

/* Includes */
#include <stddef.h>
#include "stm32f10x.h"
#include "GlobalDefine.h"
#include "Graphisc.h"
#include "Game.h"



/* Private typedef */
/* Private define  */


/* Private macro */
/* Private variables */


#define uint8 unsigned short int
/* Private function prototypes */
/* Private functions */

/**
**===========================================================================
**
**  Abstract: main program
**
**===========================================================================
*/
uint8 iterationEnable=0;
 void nop()
 {
 int i=0;
 i++;
 }
 void init()
 {
	 RCC_DeInit();
	 RCC_HSEConfig(RCC_HSE_ON);
	 RCC_WaitForHSEStartUp();
	 RCC_PLLConfig(RCC_PLLSource_HSE_Div1,RCC_PLLMul_8);
	 FLASH_SetLatency(FLASH_Latency_1);
	 RCC_PLLCmd(ENABLE);
	  while (RCC_GetFlagStatus(RCC_FLAG_PLLRDY) == RESET)
	    {
	    }
	  RCC_SYSCLKConfig(RCC_SYSCLKSource_PLLCLK);
	  while (RCC_GetSYSCLKSource() != 0x08)
	      {
	      }
	 RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOB, ENABLE);
	 GPIO_InitTypeDef GPIO_InitStruct;
	 GPIO_InitStruct.GPIO_Pin = GPIO_Pin_2|GPIO_Pin_1;
	 GPIO_InitStruct.GPIO_Mode = GPIO_Mode_Out_OD;
	 GPIO_InitStruct.GPIO_Speed = GPIO_Speed_50MHz;
	 GPIO_Init(GPIOB, &GPIO_InitStruct);
	 GPIO_InitStruct.GPIO_Mode = GPIO_Mode_AIN;
	 GPIO_InitStruct.GPIO_Speed = GPIO_Speed_50MHz;
	 GPIO_InitStruct.GPIO_Pin = GPIO_Pin_0;
	 GPIO_Init(GPIOB, &GPIO_InitStruct);
	 RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOC, ENABLE);
	 GPIO_InitStruct.GPIO_Pin = GORA|DOL|LEWO|PRAWO;
	 GPIO_InitStruct.GPIO_Mode = GPIO_Mode_IN_FLOATING;
	 GPIO_InitStruct.GPIO_Speed = GPIO_Speed_50MHz;
	 GPIO_Init(GPIOC, &GPIO_InitStruct);

 }

void adcInit()
{
	RCC_APB2PeriphClockCmd(RCC_APB2Periph_ADC1,ENABLE);

	ADC1->SQR1  = 0x00000000;
	ADC1->SMPR2 = 0x00000028;
	ADC1->SQR3  = 0x00000008;
	ADC1->CR1   = 0x00000100;
	ADC1->CR2   = 0x000E0103;
}


int main(void)
{
	init();
	adcInit();
	lcdInit();
	ADC_SoftwareStartConvCmd(ADC1,ENABLE);
	LCDContrastSet(55);
	InitializeGame();

	while (1)
	{

		GPIO_SetBits(GPIOB,GPIO_Pin_2);
		GPIO_ResetBits(GPIOB,GPIO_Pin_1);

		GPIO_SetBits(GPIOB,GPIO_Pin_1);
		GPIO_ResetBits(GPIOB,GPIO_Pin_2);

		if(!GPIO_ReadInputDataBit(GPIOC,LEWO))
		{
			platformMove(-1);
		}
		else if(!GPIO_ReadInputDataBit(GPIOC,PRAWO))
		{
			platformMove(1);
		}
		else if(!GPIO_ReadInputDataBit(GPIOB,GPIO_Pin_5))
		{
			playStart();
		}
		if(iterationEnable==1)
		{
			Iteration();
			iterationEnable=0;
		}
	}
}
void SysTick_Handler (void)
{
	static unsigned long timetick;

	if (timetick++ >= (( (ADC1->DR)>>8)*boost ))
	{
		timetick = 0;
	iterationEnable=1;
	}
}
#ifdef  USE_FULL_ASSERT

/**
  * @brief  Reports the name of the source file and the source line number
  *   where the assert_param error has occurred.
  * @param  file: pointer to the source file name
  * @param  line: assert_param error line source number
  * @retval None
  */
void assert_failed(uint8_t* file, uint32_t line)
{
  /* User can add his own implementation to report the file name and line number,
     ex: printf("Wrong parameters value: file %s on line %d\r\n", file, line) */

  /* Infinite loop */
  while (1)
  {
  }
}
#endif

/*
 * Minimal __assert_func used by the assert() macro
 * */
void __assert_func(const char *file, int line, const char *func, const char *failedexpr)
{
  while(1)
  {}
}

/*
 * Minimal __assert() uses __assert__func()
 * */
void __assert(const char *file, int line, const char *failedexpr)
{
   __assert_func (file, line, NULL, failedexpr);
}

#ifdef USE_SEE
#ifndef USE_DEFAULT_TIMEOUT_CALLBACK
/**
  * @brief  Basic management of the timeout situation.
  * @param  None.
  * @retval sEE_FAIL.
  */
uint32_t sEE_TIMEOUT_UserCallback(void)
{
  /* Return with error code */
  return sEE_FAIL;
}
#endif
#endif /* USE_SEE */

